import SearchParamHandler from "./SearchParamHandler";
import HashParamHandler from "./HashParamHandler";
export default class UrlParamHandler {
    constructor() {
        this.searchParamHandler = new SearchParamHandler();
        this.hashParamHandler = new HashParamHandler();
    }
    getHashParam(key) {
        return this.hashParamHandler.getParam(key);
    }
    setHashParam(key, value) {
        return this.hashParamHandler.setParam(key, value);
    }
    setSearchParam(key, value) {
        return this.searchParamHandler.setParam(key, value);
    }
    getSearchParam(key, value) {
        return this.searchParamHandler.getParam(key);
    }
    deleteSearchParam(key) {
        this.searchParamHandler.deleteParam(key);
    }
    readFromUrl(url) {
        this.searchParamHandler.readFromUrl();
        this.hashParamHandler.readFromUrl();
    }
    pushState(newState = false) {
        const newHashUrl = this.hashParamHandler.toString();
        const hashHasChanged = newHashUrl !== window.location.hash;
        const oldUrl = window.location.href;
        const newUrl = window.location.origin +
            window.location.pathname +
            this.searchParamHandler.toString() +
            newHashUrl;
        if (newState) {
            window.history.pushState(null, "", newUrl);
        }
        else {
            window.history.replaceState({}, "", new URL(newUrl));
        }
        if (hashHasChanged) {
            window.dispatchEvent(new HashChangeEvent("hashchange", {
                newURL: newUrl,
                oldURL: oldUrl
            }));
        }
        if (newUrl !== oldUrl) {
            window.dispatchEvent(new PopStateEvent("popstate"));
        }
    }
}
//# sourceMappingURL=UrlParamHandler.js.map